@@ -1,13 +1,15 @@
 """Asynchronous Python client for the IPX800 v4 API."""
 
-from .ainput import AInput
-from .dinput import DInput
 from .ipx800 import (
     IPX800,
     Ipx800CannotConnectError,
     Ipx800InvalidAuthError,
     Ipx800RequestError,
 )
+
+from .ainput import AInput
+from .vainput import VAInput
+from .dinput import DInput
 from .relay import Relay
 from .vinput import VInput
 from .voutput import VOutput
@@ -26,6 +28,7 @@ __all__ = [
     "XDimmer",
     "XPWM",
     "AInput",
+    "VAInput",
     "DInput",
     "VInput",
     "VOutput",
